==> pyblish-1.6.0.tar.gz: pyblish-1.6.0/README.md <==
[![title](https://cloud.githubusercontent.com/assets/2152766/12704096/b74e8778-c84a-11e5-94f6-adc0c3c50447.png)](https://www.youtube.com/watch?v=j5uUTW702-U)

[![PyPI version][pypi-image]][pypi-link] [![Build Status](https://travis-ci.org/pyblish/pyblish.svg?branch=master)](https://travis-ci.org/pyblish/pyblish)  [![Gitter][gitter-image]](https://gitter.im/pyblish/pyblish)

### Pyblish

[pypi-image]: https://badge.fury.io/py/pyblish.svg
[pypi-link]: http://badge.fury.io/py/pyblish
[travis-image]: https://travis-ci.org/pyblish/pyblish-base.svg?branch=master
[travis-link]: https://travis-ci.org/pyblish/pyblish-base

This project contains a known working combination of supported projects.

- [Learn](http://learn.pyblish.com)
- [Chat](https://gitter.im/pyblish/pyblish)
- [Wiki](../../wiki)

[gitter-image]: https://badges.gitter.im/Join%20Chat.svg

You may also be interested in..

- [pyblish-base](https://github.com/pyblish/pyblish-base) Foundation library
- [pyblish-maya](https://github.com/pyblish/pyblish-maya) Autodesk Maya integration
- [pyblish-qml](https://github.com/pyblish/pyblish-qml) Graphical user interface

<br>
<br>
<br>

### Installation

Pyblish is available for Windows, Linux and MacOS, Python 2 and 3 via PyPI.

```bash
$ pip install pyblish
```

**Contents**

The PyPI package will install the latest known working combination of Pyblish projects, see [setup.py](../../blob/master/setup.py) for details.

<br>
<br>
<br>

### Usage

Once installed, you will find a number of new Python packages available, most prominently `pyblish.api`

```python
import pyblish.api
pyblish.api.discover()
```

See the README of each individual project for details, here are a few.

- [pyblish-base](https://github.com/pyblish/pyblish-base)
- [pyblish-qml](https://github.com/pyblish/pyblish-qml)
- [pyblish-lite](https://github.com/pyblish/pyblish-lite)
- [pyblish-standalone](https://github.com/pyblish/pyblish-standalone)
- [pyblish-maya](https://github.com/pyblish/pyblish-maya)
- [pyblish-houdini](https://github.com/pyblish/pyblish-houdini)
- [pyblish-nuke](https://github.com/pyblish/pyblish-nuke)
- [pyblish-hiero](https://github.com/pyblish/pyblish-hiero)

==> pyblish-1.7.0.tar.gz: pyblish-1.7.0/README.md <==
[![title](https://cloud.githubusercontent.com/assets/2152766/12704096/b74e8778-c84a-11e5-94f6-adc0c3c50447.png)](https://www.youtube.com/watch?v=j5uUTW702-U)

[![PyPI version][pypi-image]][pypi-link] [![Build Status](https://travis-ci.org/pyblish/pyblish.svg?branch=master)](https://travis-ci.org/pyblish/pyblish)  [![Gitter][gitter-image]](https://gitter.im/pyblish/pyblish)

### Pyblish

[pypi-image]: https://badge.fury.io/py/pyblish.svg
[pypi-link]: http://badge.fury.io/py/pyblish
[travis-image]: https://travis-ci.org/pyblish/pyblish-base.svg?branch=master
[travis-link]: https://travis-ci.org/pyblish/pyblish-base

This project contains a known (but possibly old!) working combination of supported projects. See each corresponding project for latest up to date information, along with our forum and chat room below.

- [Learn](http://learn.pyblish.com)
- [Chat](https://gitter.im/pyblish/pyblish)
- [Wiki](../../wiki)

[gitter-image]: https://badges.gitter.im/Join%20Chat.svg

You may also be interested in..

- [pyblish-base](https://github.com/pyblish/pyblish-base) Foundation library
- [pyblish-maya](https://github.com/pyblish/pyblish-maya) Autodesk Maya integration
- [pyblish-qml](https://github.com/pyblish/pyblish-qml) Graphical user interface

<br>
<br>
<br>

### Installation

Pyblish is available for Windows, Linux and MacOS, Python 2 and 3 via PyPI.

```bash
$ pip install pyblish
```

**Contents**

The PyPI package will install the latest known working combination of Pyblish projects, see [setup.py](../../blob/master/setup.py) for details.

<br>
<br>
<br>

### Usage

Once installed, you will find a number of new Python packages available, most prominently `pyblish.api`

```python
import pyblish.api
pyblish.api.discover()
```

See the README of each individual project for details, here are a few.

- [pyblish-base](https://github.com/pyblish/pyblish-base)
- [pyblish-qml](https://github.com/pyblish/pyblish-qml)
- [pyblish-lite](https://github.com/pyblish/pyblish-lite)
- [pyblish-standalone](https://github.com/pyblish/pyblish-standalone)
- [pyblish-maya](https://github.com/pyblish/pyblish-maya)
- [pyblish-houdini](https://github.com/pyblish/pyblish-houdini)
- [pyblish-nuke](https://github.com/pyblish/pyblish-nuke)
- [pyblish-hiero](https://github.com/pyblish/pyblish-hiero)
